@@ -1,6 +1,6 @@
 package Courriel::Part::Multipart;
 BEGIN {
-  $Courriel::Part::Multipart::VERSION = '0.12';
+  $Courriel::Part::Multipart::VERSION = '0.13';
 }
 
 use strict;
@@ -40,11 +40,14 @@ sub BUILD {
     my $self = shift;
 
     # XXX - this is a nasty hack but I'm not sure if it can better. We want
-    # the boundary in the ContentType object to match the one in this
-    # part. There are more such hacks to come.
-    if ( $self->_has_boundary() && $self->_has_content_type() ) {
+    # the boundary in the ContentType object to match the one in this part.
+    if ( $self->_has_boundary() ) {
         $self->content_type()->_attributes()->{boundary} = $self->boundary();
     }
+    else {
+        # This is being called to force the builder to run.
+        $self->boundary();
+    }
 
     return;
 }
@@ -119,7 +122,7 @@ Courriel::Part::Multipart - A part which contains other parts
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
